==> apache-arrow-rs-21.0.0.tar.gz: apache-arrow-rs-21.0.0/arrow/benches/decimal_validate.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#[macro_use]
extern crate criterion;

use arrow::array::{
    Array, Decimal128Array, Decimal128Builder, Decimal256Array, Decimal256Builder,
};
use criterion::Criterion;
use num::BigInt;
use rand::Rng;

extern crate arrow;

use arrow::util::decimal::Decimal256;

fn validate_decimal128_array(array: Decimal128Array) {
    array.with_precision_and_scale(35, 0).unwrap();
}

fn validate_decimal256_array(array: Decimal256Array) {
    array.with_precision_and_scale(35, 0).unwrap();
}

fn validate_decimal128_benchmark(c: &mut Criterion) {
    let mut rng = rand::thread_rng();
    let size: i128 = 20000;
    let mut decimal_builder = Decimal128Builder::new(size as usize, 38, 0);
    for _ in 0..size {
        decimal_builder
            .append_value(rng.gen_range::<i128, _>(0..999999999999))
            .unwrap();
    }
    let decimal_array = decimal_builder.finish();
    let data = decimal_array.into_data();
    c.bench_function("validate_decimal128_array 20000", |b| {
        b.iter(|| {
            let array = Decimal128Array::from(data.clone());
            validate_decimal128_array(array);
        })
    });
}

fn validate_decimal256_benchmark(c: &mut Criterion) {
    let mut rng = rand::thread_rng();
    let size: i128 = 20000;
    let mut decimal_builder = Decimal256Builder::new(size as usize, 76, 0);
    for _ in 0..size {
        let v = rng.gen_range::<i128, _>(0..999999999999999);
        let decimal = Decimal256::from_big_int(&BigInt::from(v), 76, 0).unwrap();
        decimal_builder.append_value(&decimal).unwrap();
    }
    let decimal_array256_data = decimal_builder.finish();
    let data = decimal_array256_data.into_data();
    c.bench_function("validate_decimal256_array 20000", |b| {
        b.iter(|| {
            let array = Decimal256Array::from(data.clone());
            validate_decimal256_array(array);
        })
    });
}

criterion_group!(
    benches,
    validate_decimal128_benchmark,
    validate_decimal256_benchmark,
);
criterion_main!(benches);

==> apache-arrow-rs-24.0.0.tar.gz: apache-arrow-rs-24.0.0/arrow/benches/decimal_validate.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#[macro_use]
extern crate criterion;

use arrow::array::{
    Array, Decimal128Array, Decimal128Builder, Decimal256Array, Decimal256Builder,
};
use criterion::Criterion;
use num::BigInt;
use rand::Rng;

extern crate arrow;

use arrow::util::decimal::Decimal256;

fn validate_decimal128_array(array: Decimal128Array) {
    array.with_precision_and_scale(35, 0).unwrap();
}

fn validate_decimal256_array(array: Decimal256Array) {
    array.with_precision_and_scale(35, 0).unwrap();
}

fn validate_decimal128_benchmark(c: &mut Criterion) {
    let mut rng = rand::thread_rng();
    let size: i128 = 20000;
    let mut decimal_builder = Decimal128Builder::with_capacity(size as usize, 38, 0);
    for _ in 0..size {
        decimal_builder
            .append_value(rng.gen_range::<i128, _>(0..999999999999))
            .unwrap();
    }
    let decimal_array = decimal_builder.finish();
    let data = decimal_array.into_data();
    c.bench_function("validate_decimal128_array 20000", |b| {
        b.iter(|| {
            let array = Decimal128Array::from(data.clone());
            validate_decimal128_array(array);
        })
    });
}

fn validate_decimal256_benchmark(c: &mut Criterion) {
    let mut rng = rand::thread_rng();
    let size: i128 = 20000;
    let mut decimal_builder = Decimal256Builder::with_capacity(size as usize, 76, 0);
    for _ in 0..size {
        let v = rng.gen_range::<i128, _>(0..999999999999999);
        let decimal = Decimal256::from_big_int(&BigInt::from(v), 76, 0).unwrap();
        decimal_builder.append_value(&decimal).unwrap();
    }
    let decimal_array256_data = decimal_builder.finish();
    let data = decimal_array256_data.into_data();
    c.bench_function("validate_decimal256_array 20000", |b| {
        b.iter(|| {
            let array = Decimal256Array::from(data.clone());
            validate_decimal256_array(array);
        })
    });
}

criterion_group!(
    benches,
    validate_decimal128_benchmark,
    validate_decimal256_benchmark,
);
criterion_main!(benches);
